pub struct Attr {
pub key: Ident,
}Expand description
#[query] “Custom-Header”: my_function(self.url)
This would signify a header that is dependent on the query, and so is added at the time of the query being built/sent, rather then when the client is built.
Fields
key: IdentTrait Implementations